@@ -1,8 +1,9 @@
 import platform
 import socket
 import shutil
-from ..utils import run_cmd
 import click
+from helper import __version__
+from helper.utils import run_cmd
 
 def get_internal_ip():
     """Get the internal IP address based on the operating system."""
@@ -23,5 +24,17 @@ def get_internal_ip():
 
 @click.command()
 def internal_ip():
-    """Show local/internal IP"""
-    get_internal_ip()
+    """Display the local/internal IP address.
+    
+    This command shows the internal (LAN) IP address of your machine.
+    It automatically detects the correct network interface based on your OS.
+    
+    Examples:
+        $ h ip
+        192.168.1.100
+        
+    Note: On multi-homed systems, this shows the primary network interface's IP.
+    """
+    ip = get_internal_ip()
+    if ip:
+        click.echo(ip)
